@@ -19,6 +19,7 @@ from __future__ import annotations
 import logging
 import os
 import signal
+import sys
 from datetime import datetime
 from http import HTTPStatus
 from multiprocessing import Process
@@ -60,6 +61,11 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
+if sys.platform == "darwin":
+    setproctitle = lambda title: logger.debug("Mac OS detected, skipping setproctitle")
+else:
+    from setproctitle import setproctitle
+
 
 def _edge_hostname() -> str:
     """Get the hostname of the edge worker that should be reported by tasks."""
@@ -176,8 +182,6 @@ class EdgeWorker:
         def _run_job_via_supervisor(
             workload: ExecuteTask,
         ) -> int:
-            from setproctitle import setproctitle
-
             from airflow.sdk.execution_time.supervisor import supervise
 
             # Ignore ctrl-c in this process -- we don't want to kill _this_ one. we let tasks run to completion
